#!/bin/bash
#
# updated by WIPAT 2555-03-08
# updated by WIBOON 2559-11-02 added comments for clear.
#
# exit 0 is valid ; exit > 0 is invalid

CHECK_PREBLACKLIST="YES"
PREBLACKLIST_FILE="/etc/freeradius/preblacklist.txt"
#
#set default to 1.linux account and 2.PSU Passport web service.
#
# AUTHEN_SHADOW mean using linux account on this server.
AUTHEN_SHADOW="YES"
# AUTHEN_AD_LDAP mean using php-ldap method (LDAPS) in user authentication.
# must registered server IP to Computer Center.
AUTHEN_AD_LDAP="NO"
# AUTHEN_PSU_PASSPORT mean using web service method in user authentication.
AUTHEN_PSU_PASSPORT="YES"
# Others.
AUTHEN_PSU_MAIL="NO"
DEFAULT_PSU_MAIL_SERVER="mail.psu.ac.th"
AUTHEN_MAIL="NO"
DEFAULT_MAIL_SERVER="gmail.com"
AUTHEN_LDAP="NO" # PSU LDAP only (Simple LDAP)
AUTHEN_SSH="NO"
SSH_SERVER="server.domain"

NAME=$(echo ${USER_NAME} | cut -d'"' -f2)
if [ "${CHECK_PREBLACKLIST}" = "YES" ] ; then
  if [ -s ${PREBLACKLIST_FILE} ] ; then
    OUTPUT=$(grep "^${NAME}\$" ${PREBLACKLIST_FILE})
    if [ -n "${OUTPUT}" ] ; then
      echo "userlock"
      exit 6
    fi
  fi
fi
PASSWORD=$(echo ${USER_PASSWORD} | cut -d'"' -f 2-|sed "s/\"$//")
KEY="false"
MYKEY=""
if [ "${AUTHEN_SHADOW}" = "YES" ] ; then
  KEY=$(/bin/sh /etc/freeradius/check-shadow.sh "${NAME}" "${PASSWORD}")
  MYKEY=$(echo $KEY|grep -i -w "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found shadow"
    exit 0
  fi
fi
# 2557-10-31 Added a php script to check LDAPS on Microsoft AD or OpenLDAP
if [ "${AUTHEN_AD_LDAP}" = "YES" ] ; then
  USER=$(echo ${NAME} | cut -d'@' -f1)
  KEY=$(/usr/bin/php /etc/freeradius/check-ad-ldap.php ${USER} ${PASSWORD} 127.0.0.1)
  MYKEY=$(echo $KEY|grep -i "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found ldap"
    exit 0
  fi
fi
if [ "${AUTHEN_PSU_PASSPORT}" = "YES" ] ; then
  USER=$(echo ${NAME} | cut -d'@' -f1)
  KEY=$(/usr/bin/php /etc/freeradius/soap-authen.php ${USER} ${PASSWORD} $1 $2)
  MYKEY=$(echo ${KEY}|grep -i "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found psu passport"
    exit 0
  fi
fi
if [ "${AUTHEN_PSU_MAIL}" = "YES" ] ; then
  IS_EMAIL=$(echo ${NAME}|grep "@")
  if [ -n "${IS_EMAIL}" ] ; then
    USER=$(echo ${NAME} | cut -d'@' -f1)
    DOMAIN=$(echo ${NAME} | cut -d'@' -f2)
  else
    USER=${NAME}
    DOMAIN=${DEFAULT_PSU_MAIL_SERVER}
  fi
  case ${DOMAIN} in
  psu.ac.th) 
    HOST="mail.psu.ac.th" 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-imap.exp" ;;
  mail.psu.ac.th) 
    HOST="mail.psu.ac.th" 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-imap.exp" ;;
  eng.psu.ac.th) 
    HOST="mail.eng.psu.ac.th:995" 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3s-gmail.exp" ;;
  pharmacy.psu.ac.th) 
    HOST="mail.pharmacy.psu.ac.th" 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-imap.exp" ;;
  pn.psu.ac.th) 
    HOST="bunga.pn.psu.ac.th" 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-imap.exp" ;;
  esac
  KEY=$(${MYSCRIPT} ${HOST} "${USER}" "${PASSWORD}")
  MYKEY=$(echo $KEY|grep -i -w "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found psu mail"
    exit 0
  fi
fi
if [ "${AUTHEN_MAIL}" = "YES" ] ; then
  IS_EMAIL=$(echo ${NAME}|grep "@")
  if [ -n "${IS_EMAIL}" ] ; then
    USER=$(echo ${NAME} | cut -d'@' -f1)
    DOMAIN=$(echo ${NAME} | cut -d'@' -f2)
  else
    USER=${NAME}
    DOMAIN=${DEFAULT_MAIL_SERVER}
  fi
  case ${DOMAIN} in
  gmail.com) 
    HOST="pop.gmail.com:995" 
    USER=${NAME}
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3s-gmail.exp" ;;
  hotmail.com) 
    HOST="pop3.live.com:995" 
    USER=${NAME}
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3s-hotmail.exp" ;;
  live.com) 
    HOST="pop3.live.com:995" 
    USER=${NAME}
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3s-hotmail.exp" ;;
  yahoo.com) 
    HOST="pop.mail.yahoo.com:995" 
    USER=${NAME}
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3s-gmail.exp" ;;
  *)
    HOST=${DOMAIN} 
    MYSCRIPT="/usr/bin/expect /etc/freeradius/check-pop3.exp" ;;
  esac
  KEY=$(${MYSCRIPT} ${HOST} "${USER}" "${PASSWORD}")
  MYKEY=$(echo $KEY|grep -i -w "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found mail"
    exit 0
  fi
fi
if [ "${AUTHEN_LDAP}" = "YES" ] ; then
  KEY=$(/bin/sh /etc/freeradius/check-ldap.sh "${NAME}" "${PASSWORD}")
  MYKEY=$(echo $KEY|grep -i -w "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found ldap"
    exit 0
  fi
fi
if [ "${AUTHEN_SSH}" = "YES" ] ; then
  KEY=$(/usr/bin/expect /etc/freeradius/check-ssh.exp ${SSH_SERVER} "${NAME}" "${PASSWORD}")
  MYKEY=$(echo $KEY|grep -i -w "true")
  if [ -n "${MYKEY}" ] ; then
    echo "found ssh"
    exit 0
  fi
fi
echo "notfound"
exit 7
#
